import * as prompts from "@clack/prompts";
import chalk from "chalk";
import * as fs from "fs/promises";
import path from "node:path";
import * as process from "node:process";
import { logLine } from "../shared/cli/lines.js";
import { filterPromptCancel } from "../shared/prompts.js";
const allowedModes = ["create", "initialize", "migrate"];
function isMode(input) {
  return allowedModes.includes(input);
}
function label(base, text) {
  return `${chalk.bold(base)} ${text}`;
}
async function promptForMode(input) {
  if (input) {
    if (!isMode(input)) {
      return {
        mode: new Error(
          `Unknown --mode: ${input}. Allowed modes are: ${allowedModes.join(
            ", "
          )}.`
        )
      };
    }
    return { mode: input };
  }
  const dir = await fs.readdir(".");
  if (dir.length === 0) {
    const mode = filterPromptCancel(
      await prompts.select({
        message: chalk.blue("How would you like to use the template?"),
        options: [
          {
            label: label(
              "create",
              "a new repository in the current empty directory"
            ),
            value: "create-current"
          },
          {
            label: label("create", "a new repository in a new child directory"),
            value: "create-child"
          }
        ]
      })
    );
    const directory = path.basename(process.cwd());
    return {
      mode: "create",
      ...mode === "create-current" && {
        options: {
          directory: ".",
          repository: directory
        }
      }
    };
  }
  if (dir.includes(".git")) {
    return {
      mode: filterPromptCancel(
        await prompts.select({
          initialValue: "migrate",
          message: chalk.blue("How would you like to use the template?"),
          options: [
            {
              label: label("create", "a new repository in a child directory"),
              value: "create"
            },
            {
              label: label(
                "initialize",
                "a freshly cloned repository in the current directory"
              ),
              value: "initialize"
            },
            {
              label: label(
                "migrate",
                "the existing repository in the current directory"
              ),
              value: "migrate"
            }
          ]
        })
      )
    };
  }
  logLine();
  logLine(
    chalk.gray(
      "Defaulting to --mode create because the directory contains children and isn't a Git repository."
    )
  );
  return {
    mode: "create"
  };
}
export {
  promptForMode
};
//# sourceMappingURL=promptForMode.js.map