import { allArgOptions } from "../shared/options/args.js";
function getFirstMatchingArg(key) {
  return Object.keys(allArgOptions).find(
    (arg) => arg.replaceAll("-", "") === key.toLowerCase()
  );
}
function createRerunSuggestion(options) {
  const optionsNormalized = {
    ...options,
    ...options.email ? {
      email: void 0,
      emailGitHub: options.email.github,
      emailNpm: options.email.npm
    } : { email: void 0 },
    ...options.logo ? {
      logo: options.logo.src,
      logoAlt: options.logo.alt
    } : { logo: void 0 }
  };
  const args = Object.entries(optionsNormalized).sort(
    ([a], [b]) => a === "base" ? -1 : b === "base" ? 1 : a.localeCompare(b)
  ).filter(([, value]) => !!value).map(([key, value]) => {
    return `--${getFirstMatchingArg(key)} ${stringifyValue(value)}`;
  }).join(" ");
  return `npx create-typescript-app --mode ${options.mode} ${args}`;
}
function stringifyValue(value) {
  if (Array.isArray(value)) {
    return stringifyValue(value.join(" "));
  }
  const valueStringified = `${value}`;
  return valueStringified.includes(" ") ? `"${valueStringified}"` : valueStringified;
}
export {
  createRerunSuggestion
};
//# sourceMappingURL=createRerunSuggestion.js.map